Crawl status
============

The crawl status page displays real-time information on crawlers and documents being crawled. It can be accessed from the :doc:`../admin_ui`, by clicking on ``Crawl status``.

.. image:: ../../../tests/robotframework/screenshots/crawl_status.png
   :class: sosse-screenshot
